@@ -55,7 +55,7 @@ def map_json(mapping_config, json_data, strict=False):
                 list_result = []
                 list_json = walk_dict(json_data, key, strict)
                 if dict == type(list_json):
-                    list_result.append(list_json[config])
+                    list_result.append(list_json.get(config))
                 else:
                     for lj in list_json:
                         if config in lj:
